@@ -5,6 +5,7 @@ from pyrgg.functions import *
 from pyrgg.params import *
 import time
 import sys
+import argparse
 import doctest
 from art import tprint
 
@@ -23,7 +24,8 @@ GENERATOR_MENU = {
     12: gl_maker,
     13: gdf_maker,
     14: gml_maker,
-    15: gexf_maker}
+    15: gexf_maker,
+    16: dot_maker}
 
 
 def gen_graph(input_dict, file_name):
@@ -103,20 +105,28 @@ def run():
         line(40)
 
 
-if __name__ == "__main__":
-    tprint("Pyrgg", "larry3d")
-    tprint("v" + PYRGG_VERSION)
-    description_print()
-    args = sys.argv
-    if len(args) > 1:
-        if args[1].upper() == "TEST":
-            error_flag = doctest.testfile("test.py", verbose=False)[0]
-            sys.exit(error_flag)
-        else:
-            print("Bad Input!")
-            print("Test (Run doctest)")
-            print("Without arg --> Normal Run")
+def main():
+    """
+    CLI main function.
+
+    :return: None
+    """
+    parser = argparse.ArgumentParser()
+    parser.add_argument('--version', help='version', nargs="?", const=1)
+    parser.add_argument('test', help='test', nargs="?", const=1)
+    args = parser.parse_args()
+    if args.version:
+        print(PYRGG_VERSION)
+    elif args.test:
+        print("Testing ...")
+        error_flag = doctest.testfile("test.py", verbose=False)[0]
+        if error_flag == 0:
+            print("Done!")
+        sys.exit(error_flag)
     else:
+        tprint("Pyrgg", "larry3d")
+        tprint("v" + PYRGG_VERSION)
+        description_print()
         EXIT_FLAG = False
         while not EXIT_FLAG:
             run()
@@ -124,3 +134,7 @@ if __name__ == "__main__":
                 input("Press [R] to restart Pyrgg or any other key to exit."))
             if INPUTINDEX.upper() != "R":
                 EXIT_FLAG = True
+
+
+if __name__ == "__main__":
+    main()
