@@ -1,17 +1,14 @@
 # -*- coding: utf-8 -*-
 """Pyrgg functions module."""
 import datetime
-import json
+from json import loads as json_loads
 import os
-import pickle
-import random
-import textwrap
-import yaml
+from pickle import dump as pickle_dump
+from random import randint, uniform, choice
+from textwrap import fill
+from yaml import safe_dump as yaml_dump
 import pyrgg.params
 
-# random_system=random.SystemRandom()
-random_system = random
-
 
 def is_weighted(max_weight, min_weight, signed):
     """
@@ -112,7 +109,7 @@ def description_print():
     print(pyrgg.params.PYRGG_LINKS)
     line(40)
     print("\n")
-    print(textwrap.fill(pyrgg.params.PYRGG_DESCRIPTION, width=100))
+    print(fill(pyrgg.params.PYRGG_DESCRIPTION, width=100))
     print("\n")
     line(40)
 
@@ -179,9 +176,9 @@ def logger(
     :type vertices_number:int
     :param edge_number: number of edges
     :type edge_number: int
-    :param max_edge: maximum number of edges
+    :param max_edge: maximum number of edges (connected to each vertex)
     :type max_edge: int
-    :param min_edge: minimum number of edges
+    :param min_edge: minimum number of edges (connected to each vertex)
     :type min_edge: int
     :param directed: directed
     :type directed: int
@@ -202,21 +199,21 @@ def logger(
     try:
         with open("logfile.log", "a") as file:
             file.write(pyrgg.params.PYRGG_LOGGER_TEMPLATE.format(datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S'),
-                                                    file_name,
-                                                    str(vertices_number),
-                                                    str(edge_number),
-                                                    str(max_edge),
-                                                    str(min_edge),
-                                                    str(bool(directed)),
-                                                    str(bool(signed)),
-                                                    str(bool(multigraph)),
-                                                    str(bool(self_loop)),
-                                                    str(is_weighted(max_weight,
-                                                                    min_weight,
-                                                                    bool(signed))),
-                                                    str(max_weight),
-                                                    str(min_weight),
-                                                    elapsed_time))
+                                                                 file_name,
+                                                                 str(vertices_number),
+                                                                 str(edge_number),
+                                                                 str(max_edge),
+                                                                 str(min_edge),
+                                                                 str(bool(directed)),
+                                                                 str(bool(signed)),
+                                                                 str(bool(multigraph)),
+                                                                 str(bool(self_loop)),
+                                                                 str(is_weighted(max_weight,
+                                                                                 min_weight,
+                                                                                 bool(signed))),
+                                                                 str(max_weight),
+                                                                 str(min_weight),
+                                                                 elapsed_time))
     except Exception:
         print(pyrgg.params.PYRGG_LOGGER_ERROR_MESSAGE)
 
@@ -350,13 +347,15 @@ def _update_using_second_menu(result_dict, input_func):
     :return: result_dict as dict
     """
     MENU_ITEMS_KEYS2 = sorted(list(pyrgg.params.MENU_ITEMS2.keys()))
-    for item in MENU_ITEMS_KEYS2:
-        if not result_dict["weight"] and item in ["max_weight", "min_weight"]:
+    for index in MENU_ITEMS_KEYS2:
+        item1 = pyrgg.params.MENU_ITEMS2[index][0]
+        item2 = pyrgg.params.MENU_ITEMS2[index][1]
+        if not result_dict["weight"] and item1 in ["max_weight", "min_weight"]:
             continue
         while True:
             try:
-                result_dict[item] = MENU_ITEM_CONVERTORS[item](
-                    input_func(pyrgg.params.MENU_ITEMS2[item])
+                result_dict[item1] = MENU_ITEM_CONVERTORS[item1](
+                    input_func(item2)
                 )
             except Exception:
                 print(pyrgg.params.PYRGG_INPUT_ERROR_MESSAGE)
@@ -365,65 +364,35 @@ def _update_using_second_menu(result_dict, input_func):
     return result_dict
 
 
-def _threshold_calc(random_edge, max_edge, vertex_degree):
+def _threshold_calc(min_edge, max_edge, vertex_degree):
     """
     Calculate threshold for branch_gen function.
 
-    :param random_edge: number of vertex edges
-    :type random_edge: int
-    :param max_edge : maximum edge number
-    :type max_edge : int
+    :param min_edge: minimum number of edges (connected to each vertex)
+    :type min_edge: int
+    :param max_edge: maximum number of edges (connected to each vertex)
+    :type max_edge: int
     :param vertex_degree: vertex degree
     :type vertex_degree: int
     :return: threshold as int
     """
-    threshold = min(random_edge, abs(max_edge - vertex_degree))
-    return threshold
-
-
-def sign_gen():
-    """
-    Return random sign.
-
-    :return: 1 or -1
-    """
-    flag = random_system.randint(0, 1)
-    if flag == 0:
-        return 1
-    return -1
-
-
-def random_edge_limits(vertex_index, min_edge, max_edge, degree_dict):
-    """
-    Calculate random_edge parameter limits.
-
-    :param vertex_index: vertex index
-    :type vertex_index: int
-    :param min_edge: minimum edge number
-    :type min_edge: int
-    :param max_edge : maximum edge number
-    :type max_edge : int
-    :param degree_dict: all vertices degree
-    :type degree_dict: dict
-    :return: status,lower_limit,upper_limit
-    """
+    threshold = min_edge
     lower_limit = 0
-    status = False
-    vertex_degree = degree_dict[vertex_index]
     upper_limit = max_edge - vertex_degree
     if vertex_degree < min_edge:
         lower_limit = min_edge - vertex_degree
     if upper_limit > lower_limit:
-        status = True
-    return status, lower_limit, upper_limit
+        threshold = randint(lower_limit, upper_limit)
+    return threshold
 
 
 def branch_gen(
         vertex_index,
         max_edge,
-        random_edge,
+        min_edge,
         min_weight,
         max_weight,
+        precision,
         sign,
         direct,
         self_loop,
@@ -436,14 +405,16 @@ def branch_gen(
 
     :param vertex_index: origin vertex index
     :type vertex_index: int
-    :param max_edge : maximum edge number
-    :type max_edge : int
-    :param random_edge: number of vertex edges
-    :type random_edge: int
+    :param max_edge: maximum number of edges (connected to each vertex)
+    :type max_edge: int
+    :param min_edge: minimum number of edges (connected to each vertex)
+    :type min_edge: int
     :param min_weight: weight min range
     :type min_weight: int
     :param max_weight: weight max range
     :type max_weight: int
+    :param precision: numbers precision
+    :type precision: int
     :param sign: weight sign flag
     :type sign: bool
     :param direct: directed and undirected graph flag
@@ -464,26 +435,22 @@ def branch_gen(
     branch_list = []
     weight_list = []
     reference_vertices = []
-    max_weight_flag = is_float(max_weight)
-    min_weight_flag = is_float(min_weight)
-    weight_float_flag = min_weight_flag or max_weight_flag
-    random_unit = random_system.randint
+    random_unit = randint
     vertex_degree = degree_dict[vertex_index]
+    if vertex_degree >= max_edge:
+        return [branch_list, weight_list]
     threshold = _threshold_calc(
-        random_edge=random_edge,
+        min_edge=min_edge,
         max_edge=max_edge,
         vertex_degree=vertex_degree)
     for i in range(max_edge + 1):
         reference_vertices.extend(list(degree_sort_dict[i].values()))
         if len(reference_vertices) >= threshold:
             break
-    weight_precision = max(
-        get_precision(max_weight),
-        get_precision(min_weight))
-    if weight_float_flag:
-        random_unit = random_system.uniform
+    if precision > 0:
+        random_unit = uniform
     if not direct and (
-            vertex_index in used_vertices.keys()) and not multigraph:
+            vertex_index in used_vertices) and not multigraph:
         reference_vertices = list(
             set(reference_vertices) - set(used_vertices[vertex_index]))
     if not self_loop and vertex_index in reference_vertices:
@@ -496,7 +463,7 @@ def branch_gen(
             break
         if len(reference_vertices) == 0:
             break
-        random_tail_index = random_system.choice(
+        random_tail_index = choice(
             range(len(reference_vertices)))
         random_tail = reference_vertices[random_tail_index]
         random_tail_degree = degree_dict[random_tail]
@@ -506,27 +473,25 @@ def branch_gen(
             reference_vertices.pop(random_tail_index)
             continue
         if not direct:
-            if random_tail in used_vertices.keys():
+            try:
                 used_vertices[random_tail].append(vertex_index)
-            else:
+            except KeyError:
                 used_vertices[random_tail] = [vertex_index]
+        weight_sign = 1
         if sign:
-            random_weight = sign_gen() * random_unit(min_weight, max_weight)
-        else:
-            random_weight = random_unit(min_weight, max_weight)
-        if weight_float_flag:
-            random_weight = round(random_weight, weight_precision)
+            weight_sign = choice([1, -1])
+        random_weight = weight_sign * random_unit(min_weight, max_weight)
+        random_weight = round(random_weight, precision)
         branch_list.append(random_tail)
         weight_list.append(random_weight)
         index += 1
         del degree_sort_dict[vertex_degree][vertex_index]
-        if random_tail != vertex_index:
-            del degree_sort_dict[random_tail_degree][random_tail]
         degree_dict[random_tail] += 1
         degree_dict[vertex_index] += 1
         degree_sort_dict[degree_dict[vertex_index]
                          ][vertex_index] = vertex_index
         if random_tail != vertex_index:
+            del degree_sort_dict[random_tail_degree][random_tail]
             degree_sort_dict[degree_dict[random_tail]
                              ][random_tail] = random_tail
         if not multigraph:
@@ -553,10 +518,10 @@ def edge_gen(
     :type min_weight: int
     :param max_weight: weight max range
     :type max_weight: int
-    :param min_edge : minimum edge number
-    :type min_edge : int
-    :param max_edge : maximum edge number
-    :type max_edge : int
+    :param min_edge: minimum number of edges (connected to each vertex)
+    :type min_edge: int
+    :param max_edge: maximum number of edges (connected to each vertex)
+    :type max_edge: int
     :param sign: weight sign flag
     :type sign: bool
     :param direct: directed and undirected graph flag
@@ -567,33 +532,34 @@ def edge_gen(
     :type multigraph: bool
     :return: list of dicts
     """
+    precision = max(
+        get_precision(max_weight),
+        get_precision(min_weight))
     temp = 0
     vertices_id = list(range(1, vertices_number + 1))
     vertices_edge = []
     weight_list = []
     used_vertices = {}
-    degree_dict = {i: 0 for i in vertices_id}
     degree_sort_dict = {i: {} for i in range(max_edge + 1)}
-    degree_sort_dict[0] = {i: i for i in vertices_id}
-    random_edge = min_edge
+    degree_dict = {}
     for i in vertices_id:
-        status, lower_limit, upper_limit = random_edge_limits(
-            i, min_edge, max_edge, degree_dict)
-        if status:
-            random_edge = random_system.randint(lower_limit, upper_limit)
-        temp_list = branch_gen(
-            i,
-            max_edge,
-            random_edge,
-            min_weight,
-            max_weight,
-            sign,
-            direct,
-            self_loop,
-            multigraph,
-            used_vertices,
-            degree_dict,
-            degree_sort_dict)
+        degree_dict[i] = 0
+        degree_sort_dict[0][i] = i
+    branch_gen_params = {
+        "max_edge": max_edge,
+        "min_edge": min_edge,
+        "min_weight": min_weight,
+        "max_weight": max_weight,
+        "sign": sign,
+        "direct": direct,
+        "self_loop": self_loop,
+        "multigraph": multigraph,
+        "used_vertices": used_vertices,
+        "degree_dict": degree_dict,
+        "degree_sort_dict": degree_sort_dict,
+        "precision": precision}
+    for i in vertices_id:
+        temp_list = branch_gen(vertex_index=i, **branch_gen_params)
         vertices_edge.append(temp_list[0])
         weight_list.append(temp_list[1])
         temp = temp + len(temp_list[0])
@@ -611,9 +577,9 @@ def json_to_yaml(filename):
     """
     try:
         with open(filename + ".json", "r") as json_file:
-            json_data = json.loads(json_file.read())
+            json_data = json_loads(json_file.read())
             with open(filename + ".yaml", "w") as yaml_file:
-                yaml.safe_dump(json_data, yaml_file, default_flow_style=False)
+                yaml_dump(json_data, yaml_file, default_flow_style=False)
     except FileNotFoundError:
         print(pyrgg.params.PYRGG_FILE_ERROR_MESSAGE)
 
@@ -628,8 +594,8 @@ def json_to_pickle(filename):
     """
     try:
         with open(filename + ".json", "r") as json_file:
-            json_data = json.loads(json_file.read())
+            json_data = json_loads(json_file.read())
             with open(filename + ".p", "wb") as pickle_file:
-                pickle.dump(json_data, pickle_file)
+                pickle_dump(json_data, pickle_file)
     except FileNotFoundError:
         print(pyrgg.params.PYRGG_FILE_ERROR_MESSAGE)
