@@ -77,33 +77,27 @@ Traceback (most recent call last):
 ValueError: could not convert string to float: 'sadasdasd'
 >>> line(12,"*")
 ************
->>> random.seed(2)
->>> sign_gen()
-1
->>> random.seed(11)
->>> sign_gen()
--1
 >>> used_vertices = {k:[] for k in range(1,41)}
 >>> degree_dict = {k:0 for k in range(1,41)}
 >>> degree_dict_sort = {k:{} for k in range(41)}
 >>> degree_dict_sort[0] = {i:i for i in range(1,41)}
 >>> all_vertices = list(range(1, 41))
 >>> random.seed(2)
->>> branch_gen(1,10,10,1,20,True,True,True,False,used_vertices,degree_dict,degree_dict_sort)
+>>> branch_gen(1,10,10,1,20,0,True,True,True,False,used_vertices,degree_dict,degree_dict_sort)
 [[4, 25, 18, 3, 30, 34, 2, 26, 14, 11], [3, 10, 20, 14, -18, -2, -15, -14, 8, 6]]
 >>> random.seed(20)
->>> branch_gen(1,10,4,1,20,False,True,True,False,used_vertices,degree_dict,degree_dict_sort)
+>>> branch_gen(1,10,4,1,20,0,False,True,True,False,used_vertices,degree_dict,degree_dict_sort)
 [[], []]
 >>> used_vertices = {k:[] for k in range(1,41)}
 >>> degree_dict = {k:0 for k in range(1,41)}
 >>> degree_dict_sort = {k:{} for k in range(41)}
 >>> degree_dict_sort[0] = {i:i for i in range(1,41)}
->>> branch_gen(1,10,4,1,20,False,True,True,False,used_vertices,degree_dict,degree_dict_sort)
-[[10, 7, 39, 2], [9, 11, 6, 14]]
+>>> branch_gen(1,10,4,1,20,0,False,True,True,False,used_vertices,degree_dict,degree_dict_sort)
+[[10, 7, 39, 2, 30, 9, 25, 35, 18], [9, 11, 6, 14, 3, 5, 16, 14, 7]]
 >>> branch_gen(40,1,20,1)
 Traceback (most recent call last):
         ...
-TypeError: branch_gen() missing 8 required positional arguments: 'max_weight', 'sign', 'direct', 'self_loop', 'multigraph', 'used_vertices', 'degree_dict', and 'degree_sort_dict'
+TypeError: branch_gen() missing 9 required positional arguments: 'max_weight', 'precision', 'sign', 'direct', 'self_loop', 'multigraph', 'used_vertices', 'degree_dict', and 'degree_sort_dict'
 >>> random.seed(2)
 >>> edge_gen(20,0,400,2,10,True,True,True,False)
 [{1: [3, 7], 2: [4, 17, 20, 9, 11], 3: [14, 8, 5, 12, 16, 19, 15], 4: [15, 17, 12, 8, 14, 13], 5: [16, 9, 7, 20, 19, 18, 13, 5], 6: [6, 10], 7: [18, 10, 11], 8: [], 9: [], 10: [12, 18, 8, 1, 14], 11: [9, 11], 12: [], 13: [], 14: [19, 16, 17, 20, 15], 15: [6, 1, 19], 16: [12, 13, 8, 9, 17], 17: [], 18: [9, 12, 17, 6, 20, 19, 1], 19: [13], 20: []}, {1: [184, -128], 2: [220, -278, -257, 14, -163], 3: [286, 118, 166, 261, -263, 228, -303], 4: [-82, -335, 250, -256, -338, -179], 5: [-337, -358, -395, -155, -159, 250, -350, -371], 6: [30, -302], 7: [386, -125, 216], 8: [], 9: [], 10: [127, 42, 12, 191, 80], 11: [-301, 77], 12: [], 13: [], 14: [146, -15, -282, 135, 242], 15: [-52, -65, -249], 16: [-132, -334, 343, -17, 87], 17: [], 18: [126, -37, 302, -131, -142, 77, -209], 19: [123], 20: []}, 61]
@@ -354,7 +348,7 @@ TypeError: dimacs_maker() missing 3 required positional arguments: 'direct', 'se
 148
 >>> json_to_yaml('testfile')
 >>> file=open('testfile.yaml','r')
->>> testfile_1_yaml=yaml.load(file)
+>>> testfile_1_yaml=yaml.safe_load(file)
 >>> testfile_1_yaml['graph']['edges'][1]['source']
 5
 >>> testfile_1_yaml['graph']['edges'][1]['target']
@@ -384,7 +378,7 @@ TypeError: dimacs_maker() missing 3 required positional arguments: 'direct', 'se
 5
 >>> json_to_yaml('testfile2')
 >>> file=open('testfile2.yaml','r')
->>> testfile_2_yaml=yaml.load(file)
+>>> testfile_2_yaml=yaml.safe_load(file)
 >>> testfile_2_yaml['graph']['nodes'][1]
 {'id': 2}
 >>> testfile_2_yaml['graph']['edges'][1]['source']
@@ -416,7 +410,7 @@ TypeError: dimacs_maker() missing 3 required positional arguments: 'direct', 'se
 15
 >>> json_to_yaml('testfile3')
 >>> file=open('testfile3.yaml','r')
->>> testfile_3_yaml=yaml.load(file)
+>>> testfile_3_yaml=yaml.safe_load(file)
 >>> testfile_3_yaml['graph']['nodes'][1]
 {'id': 2}
 >>> testfile_3_yaml['graph']['edges'][1]['source']
@@ -1151,7 +1145,7 @@ True
 >>> input_dic['vertices']
 20
 >>> input_dic['min_edge']
-20
+47
 >>> input_dic['min_weight']
 15
 >>> input_dic['output_format']
@@ -1161,7 +1155,7 @@ True
 >>> input_dic['file_name']
 '14'
 >>> input_dic['max_edge']
-20
+47
 >>> random.seed(2)
 >>> tgf_maker('testfile', 0, 200, 10, 0, 2, True,True,True,False)
 7
